@@ -46,6 +46,11 @@ enum {
 	PLATFORM_LIST_COL_LAST
 };
 
+enum {
+	OPERATION_COMMIT,
+	OPERATION_UPDATE
+};
+
 static void  gst_tool_class_init   (GstToolClass *class);
 static void  gst_tool_init         (GstTool      *tool);
 static void  gst_tool_finalize     (GObject      *object);
@@ -118,42 +123,42 @@ report_window_close_cb (GtkWidget *widget, GdkEventAny *event, gpointer data)
 	return TRUE;
 }
 
-static GladeXML*
-gst_tool_load_glade_common (GstTool *tool, const gchar *widget)
+static GtkBuilder *
+gst_tool_load_common_ui (GstTool *tool)
 {
-	GladeXML *xml;
-	
+	GtkBuilder *builder;
+
 	g_return_val_if_fail (tool != NULL, NULL);
 	g_return_val_if_fail (GST_IS_TOOL (tool), NULL);
-	g_return_val_if_fail (tool->glade_common_path != NULL, NULL);
+	g_return_val_if_fail (tool->common_ui_path != NULL, NULL);
 
-	xml = glade_xml_new (tool->glade_common_path, widget, NULL);
+	builder = gtk_builder_new ();
 
-	if (!xml) {
-		g_error ("Could not load %s\n", tool->glade_common_path);
+	if (!gtk_builder_add_from_file (builder, tool->common_ui_path, NULL)) {
+		g_error ("Could not load %s\n", tool->common_ui_path);
 	}
 
-	return xml;
+	return builder;
 }
 
 static void
 gst_tool_init (GstTool *tool)
 {
-	GdkPixbuf *pixbuf;
-	GladeXML  *xml;
+	GdkPixbuf  *pixbuf;
+	GtkBuilder *builder;
 
 	tool->icon_theme = gtk_icon_theme_get_default ();
-	tool->glade_common_path  = INTERFACES_DIR "/common.glade";
+	tool->common_ui_path  = INTERFACES_DIR "/common.ui";
 
 	tool->session = oobs_session_get ();
 	tool->gconf_client = gconf_client_get_default ();
 
-	xml = gst_tool_load_glade_common (tool, "report_window");
+	builder = gst_tool_load_common_ui (tool);
 
-	tool->report_window = glade_xml_get_widget (xml, "report_window");
-	tool->report_label = glade_xml_get_widget (xml, "report_label");
-	tool->report_progress = glade_xml_get_widget (xml, "report_progress");
-	tool->report_pixmap = glade_xml_get_widget (xml, "report_pixmap");
+	tool->report_window = GTK_WIDGET (gtk_builder_get_object (builder, "report_window"));
+	tool->report_label = GTK_WIDGET (gtk_builder_get_object (builder, "report_label"));
+	tool->report_progress = GTK_WIDGET (gtk_builder_get_object (builder, "report_progress"));
+	tool->report_pixmap = GTK_WIDGET (gtk_builder_get_object (builder, "report_pixmap"));
 	g_signal_connect (G_OBJECT (tool->report_window), "delete_event",
 			  G_CALLBACK (report_window_close_cb), tool);
 
@@ -163,21 +168,33 @@ gst_tool_init (GstTool *tool)
 	if (pixbuf)
 		gdk_pixbuf_unref (pixbuf);
 
-	g_object_unref (xml);
+	tool->objects = g_ptr_array_new ();
+
+	g_object_unref (builder);
 }
 
 static void
-show_access_denied_dialog (GstTool *tool)
+show_access_denied_dialog (GstTool *tool,
+			   gint     operation)
 {
 	GtkWidget *dialog;
+	const gchar *primary_text, *secondary_text;
 
-	dialog = gtk_message_dialog_new (NULL,
+	if (operation == OPERATION_UPDATE) {
+		primary_text = N_("The configuration could not be loaded");
+		secondary_text = N_("You are not allowed to access the system configuration.");
+	} else {
+		primary_text = N_("The configuration could not be saved");
+		secondary_text = N_("You are not allowed to modify the system configuration.");
+	}
+
+	dialog = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
 					 GTK_DIALOG_MODAL,
 					 GTK_MESSAGE_ERROR,
 					 GTK_BUTTONS_CLOSE,
-					 _("The configuration could not be loaded"));
+					 _(primary_text));
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("You are not allowed to access the system configuration."));
+						  _(secondary_text));
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
@@ -206,7 +223,7 @@ gst_tool_constructor (GType                  type,
 		gtk_window_set_default_icon_name (tool->icon);
 
 	if (tool->name) {
-		tool->glade_path = g_strdup_printf (INTERFACES_DIR "/%s.glade", tool->name);
+		tool->ui_path = g_strdup_printf (INTERFACES_DIR "/%s.ui", tool->name);
 
 		widget_name = g_strdup_printf ("%s_admin", tool->name);
 		tool->main_dialog = gst_dialog_new (tool, widget_name, tool->title);
@@ -220,18 +237,18 @@ gst_tool_constructor (GType                  type,
 		dialog = gst_platform_dialog_new (tool->session);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
-
-		gst_tool_update_config (tool);
 		break;
 	case OOBS_RESULT_ACCESS_DENIED:
 	case OOBS_RESULT_ERROR:
-		show_access_denied_dialog (tool);
+		show_access_denied_dialog (tool, OPERATION_UPDATE);
 		exit (-1);
 		break;
 	default:
 		break;
 	}
 
+	gst_tool_update_async (tool);
+
 	return object;
 }
 
@@ -264,7 +281,7 @@ gst_tool_finalize (GObject *object)
 	g_free (tool->name);
 	g_free (tool->title);
 	g_free (tool->icon);
-	g_free (tool->glade_path);
+	g_free (tool->ui_path);
 
 	if (tool->session)
 		g_object_unref (tool->session);
@@ -278,6 +295,8 @@ gst_tool_finalize (GObject *object)
 	if (tool->gconf_client)
 		g_object_unref (tool->gconf_client);
 
+	g_ptr_array_free (tool->objects, FALSE);
+
 	(* G_OBJECT_CLASS (gst_tool_parent_class)->finalize) (object);
 }
 
@@ -292,6 +311,8 @@ gst_tool_impl_close (GstTool *tool)
 
 	/* process pending async requests */
 	oobs_session_process_requests (tool->session);
+
+
 	g_object_unref (tool);
 	gtk_main_quit ();
 }
@@ -323,13 +344,6 @@ gst_tool_close (GstTool *tool)
 		(* GST_TOOL_GET_CLASS (tool)->close) (tool);
 }
 
-gboolean
-gst_tool_is_authenticated (GstTool *tool)
-{
-	/* FIXME */
-	return TRUE;
-}
-
 void
 gst_init_tool (const gchar *app_name, int argc, char *argv [], GOptionEntry *entries)
 {
@@ -376,12 +390,12 @@ gst_tool_show_help (GstTool *tool, gchar *section)
 				       lang,
 				       help_file_xml,
 				       NULL);
-					
+
 		if (g_file_test (uri, G_FILE_TEST_EXISTS)) {
                     break;
 		}
 	}
-	
+
 	if (section) {
 		command = g_strconcat ("gnome-help ghelp://", uri, "?", section, NULL);
 	} else {
@@ -472,6 +486,16 @@ on_commit_finalized (OobsObject *object,
 
 	gst_tool_hide_report_window (user_data->tool);
 
+	switch (result) {
+	case OOBS_RESULT_ACCESS_DENIED:
+		show_access_denied_dialog (user_data->tool, OPERATION_COMMIT);
+		break;
+	case OOBS_RESULT_OK:
+	default:
+		/* FIXME: handle other errors */
+		break;
+	}
+
 	if (user_data->func)
 		(* user_data->func) (object, result, user_data->data);
 
@@ -492,12 +516,56 @@ gst_tool_commit_async (GstTool             *tool,
 	user_data->func = func;
 	user_data->data = data;
 
-	gst_tool_show_report_window (tool, message);
+	if (message)
+		gst_tool_show_report_window (tool, message);
+
 	oobs_object_commit_async (object, on_commit_finalized, user_data);
 }
 
+static void
+update_async_func (OobsObject *object,
+		   OobsResult  result,
+		   gpointer    data)
+{
+	GstTool *tool = GST_TOOL (data);
+	gst_dialog_thaw (tool->main_dialog);
+
+	if (gst_dialog_get_freeze_level (tool->main_dialog) == 0) {
+		/* everything is now updated */
+		gst_tool_update_config (tool);
+		gst_tool_update_gui (tool);
+	}
+}
+
+void
+gst_tool_update_async (GstTool *tool)
+{
+	gint i;
+
+	g_return_if_fail (GST_IS_TOOL (tool));
+
+	for (i = 0; i < tool->objects->len; i++) {
+		OobsObject *object = g_ptr_array_index (tool->objects, i);
+
+		gst_dialog_freeze (tool->main_dialog);
+		oobs_object_update_async (object,
+					  update_async_func,
+					  tool);
+	}
+}
+
 GtkIconTheme*
 gst_tool_get_icon_theme (GstTool *tool)
 {
 	return tool->icon_theme;
 }
+
+void
+gst_tool_add_configuration_object (GstTool    *tool,
+				   OobsObject *object)
+{
+	g_return_if_fail (GST_IS_TOOL (tool));
+	g_return_if_fail (OOBS_IS_OBJECT (object));
+
+	g_ptr_array_add (tool->objects, object);
+}
