@@ -35,16 +35,17 @@ typedef struct
   const gchar *desc;
 } Description;
 
-static Description method_descriptions [] = {
+static const Description method_descriptions [] = {
   { "dhcp",   N_("Automatic configuration (DHCP)") },
   { "ipv4ll", N_("Local Zeroconf network (IPv4 LL)") },
   { "static", N_("Static IP address") },
 };
 
-static Description key_type_descriptions [] = {
+static const Description key_type_descriptions [] = {
   { "wep-ascii", N_("WEP key (ascii)") },
   { "wep-hex", N_("WEP key (hexadecimal)") },
-  { "wpa-psk", N_("WPA") },
+  { "wpa-psk", N_("WPA Personal") },
+  { "wpa2-psk", N_("WPA2 Personal") },
 };
 
 
@@ -439,10 +440,10 @@ method_to_desc (const Description  descriptions[],
 }
 
 static void
-populate_combo (GtkComboBox  *combo,
-		GList        *list,
-		Description   descriptions[],
-		gint          n_elems)
+populate_combo (GtkComboBox       *combo,
+		GList             *list,
+		const Description  descriptions[],
+		gint               n_elems)
 {
   GtkListStore *store;
   GtkTreeIter iter;
@@ -526,6 +527,8 @@ connection_dialog_init (GstTool *tool)
   gcd->isp_frame      = gst_dialog_get_widget (tool->main_dialog, "isp_data");
   gcd->account_frame  = gst_dialog_get_widget (tool->main_dialog, "isp_account_data");
 
+  gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (gcd->serial_port), 0);
+
   connection_essids_combo_init (GTK_COMBO_BOX_ENTRY (gcd->essid));
 
   return gcd;
@@ -618,7 +621,7 @@ connection_dialog_prepare (GstConnectionDialog *dialog, OobsIface *iface)
   dialog->iface = g_object_ref (iface);
   active = oobs_iface_get_configured (dialog->iface);
 
-  title = g_strdup_printf ("Settings for interface %s\n",
+  title = g_strdup_printf (_("%s Properties\n"),
 			   oobs_iface_get_device_name (dialog->iface));
   gtk_window_set_title (GTK_WINDOW (dialog->dialog), title);
   g_free (title);
