@@ -26,31 +26,75 @@
 #include <config.h>
 #include "gst.h"
 
+#ifdef HAVE_POLKIT
+#include "gst-polkit-action.h"
+#endif
+
 #include "passwd.h"
 #include "callbacks.h"
 #include "table.h"
 #include "user-settings.h"
 #include "users-table.h"
+#include "users-tool.h"
 #include "group-settings.h"
 #include "groups-table.h"
 
 extern GstTool *tool;
 
+/* Unlock signal */
+
+void
+on_unlocked (GstDialog *dialog)
+{
+	GtkWidget *users_table;
+	GtkTreeModel *model, *store;
+	GtkTreeIter iter;
+	gboolean valid;
+
+	users_table = gst_dialog_get_widget (dialog, "users_table");
+
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (users_table));
+	store = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
+
+	valid = gtk_tree_model_get_iter_first (store, &iter);
+
+	while (valid) {
+		gtk_list_store_set (GTK_LIST_STORE (store), &iter,
+				    COL_USER_SENSITIVE, TRUE,
+				    -1);
+
+		valid = gtk_tree_model_iter_next (store, &iter);
+	}
+}
+
 /* Common stuff to users and groups tables */
 
 static void
-actions_set_sensitive (gint table, gint count)
+actions_set_sensitive (gint table, gint count, OobsUser *user)
 {
 	switch (table) {
 	case TABLE_USERS:
-		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "user_new", TRUE);
-		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "user_delete", (count > 0));
-		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "user_settings", (count == 1));
+		gst_dialog_try_set_sensitive (tool->main_dialog,
+					      gst_dialog_get_widget (tool->main_dialog, "user_new"),
+					      TRUE);
+		gst_dialog_try_set_sensitive (tool->main_dialog,
+					      gst_dialog_get_widget (tool->main_dialog, "user_delete"),
+					      (count > 0));
+
+		
+		gtk_widget_set_sensitive (gst_dialog_get_widget (tool->main_dialog, "user_settings"),
+					  (count == 1 && (gst_dialog_is_authenticated (tool->main_dialog) || oobs_user_get_active (user))));
 		break;
 	case TABLE_GROUPS:
-		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "group_new", TRUE);
-		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "group_delete", (count > 0));
-		gst_dialog_widget_set_user_sensitive (tool->main_dialog, "group_settings", (count == 1));
+		gst_dialog_try_set_sensitive (tool->main_dialog,
+					      gst_dialog_get_widget (tool->main_dialog, "group_new"),
+					      TRUE);
+		gst_dialog_try_set_sensitive (tool->main_dialog,
+					      gst_dialog_get_widget (tool->main_dialog, "group_delete"),
+					      (count > 0));
+		gst_dialog_try_set_sensitive (tool->main_dialog,
+					      gst_dialog_get_widget (tool->main_dialog, "group_settings"),
+					      (count == 1));
 		break;
 	default:
 		g_assert_not_reached ();
@@ -63,11 +107,25 @@ on_table_clicked (GtkTreeSelection *selection, gpointer data)
 {
 	gint count, table;
 	gboolean active;
+	OobsUser *user = NULL;
 
 	table = GPOINTER_TO_INT (data);
 	count = gtk_tree_selection_count_selected_rows (selection);
 
-	actions_set_sensitive (table, count);
+	if (table == TABLE_USERS && count == 1 && !gst_dialog_is_authenticated (tool->main_dialog)) {
+		GtkTreeModel *model;
+		GList *selected;
+		GtkTreePath *path;
+		GtkTreeIter iter;
+
+		selected = gtk_tree_selection_get_selected_rows (selection, &model);
+		path = (GtkTreePath *) selected->data;
+
+		gtk_tree_model_get_iter (model, &iter, path);
+		gtk_tree_model_get (model, &iter, COL_USER_OBJECT, &user, -1);
+	}
+
+	actions_set_sensitive (table, count, user);
 }
 
 static void
@@ -92,10 +150,12 @@ do_popup_menu (GtkTreeView *treeview, GdkEventButton *event)
 	cont = gtk_tree_selection_count_selected_rows (selection);
 	ui_manager = g_object_get_data (G_OBJECT (treeview), "ui-manager");
 
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (ui_manager, "/MainMenu/Add"),
+				  cont == 1 && (gst_dialog_is_authenticated (tool->main_dialog)));
 	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (ui_manager, "/MainMenu/Properties"),
-				  cont == 1);
+				  cont == 1 && (gst_dialog_is_authenticated (tool->main_dialog)));
 	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (ui_manager, "/MainMenu/Delete"),
-				  cont > 0);
+				  cont > 0 && gst_dialog_is_authenticated (tool->main_dialog));
 
 	gtk_menu_popup (GTK_MENU (popup), NULL, NULL, NULL, NULL,
 			button, event_time);
@@ -130,6 +190,23 @@ on_table_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer da
 	}
 
 	if (cont != 0 && (event->type == GDK_2BUTTON_PRESS || event->type == GDK_3BUTTON_PRESS)) {
+		if (!gst_dialog_is_authenticated (tool->main_dialog)) {
+			GtkTreeModel *model;
+			GList *selected;
+			GtkTreePath *path;
+			GtkTreeIter iter;
+			OobsUser *user;
+
+			selected = gtk_tree_selection_get_selected_rows (selection, &model);
+			path = (GtkTreePath *) selected->data;
+
+			gtk_tree_model_get_iter (model, &iter, path);
+			gtk_tree_model_get (model, &iter, COL_USER_OBJECT, &user, -1);
+
+			if (!oobs_user_get_active (user))
+				return FALSE;
+		}
+
 		if (table == TABLE_USERS)
 			on_user_settings_clicked (NULL, NULL);
 		else if (table == TABLE_GROUPS)
@@ -244,8 +321,26 @@ on_user_settings_clicked (GtkButton *button, gpointer user_data)
 								  &filter_iter, &iter);
 		user_settings_dialog_get_data (user);
 		users_table_set_user (user, list_iter, &filter_iter);
-		oobs_object_commit (GST_USERS_TOOL (tool)->users_config);
-		oobs_object_commit (GST_USERS_TOOL (tool)->groups_config);
+
+		if (gst_dialog_is_authenticated (tool->main_dialog)) {
+			/* change users/groups configuration */
+			oobs_object_commit (GST_USERS_TOOL (tool)->users_config);
+			oobs_object_commit (GST_USERS_TOOL (tool)->groups_config);
+		} else {
+			OobsObject *object = GST_USERS_TOOL (tool)->self_config;
+
+			/* change self, only if it is the modified user */
+			if (user == oobs_self_config_get_user (OOBS_SELF_CONFIG (object))) {
+#ifdef HAVE_POLKIT
+				GstPolKitAction *action;
+				action = gst_polkit_action_new (oobs_object_get_authentication_action (object),
+								GTK_WIDGET (tool->main_dialog));
+
+				if (gst_polkit_action_authenticate (action))
+					oobs_object_commit (GST_USERS_TOOL (tool)->self_config);
+#endif
+			}
+		}
 	}
 
 	g_object_unref (user);
