@@ -164,9 +164,10 @@ set_main_group (OobsUser *user)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	OobsGroup *main_group, *group;
-	gboolean valid;
+	gboolean valid, found;
 
 	main_group = oobs_user_get_main_group (user);
+	found = FALSE;
 
 	if (!main_group)
 		main_group = oobs_users_config_get_default_group (OOBS_USERS_CONFIG (GST_USERS_TOOL (tool)->users_config));
@@ -175,19 +176,22 @@ set_main_group (OobsUser *user)
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
 	valid = gtk_tree_model_get_iter_first (model, &iter);
 
-	while (valid) {
+	while (valid && !found) {
 		gtk_tree_model_get (model, &iter,
 				    COL_GROUP_OBJECT, &group,
 				    -1);
 
 		if (main_group == group) {
 			gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo), &iter);
-			break;
+			found = TRUE;
 		}
 
 		g_object_unref (group);
 		valid = gtk_tree_model_iter_next (model, &iter);
 	}
+
+	if (!found)
+		gtk_combo_box_set_active (GTK_COMBO_BOX (combo), -1);
 }
 
 static OobsGroup*
@@ -345,6 +349,7 @@ user_settings_dialog_new (OobsUser *user)
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_name");
 	set_entry_text (widget, login);
 	set_login_length (widget);
+	gtk_widget_set_sensitive (widget, (login == NULL));
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_real_name");
 	set_entry_text (widget, oobs_user_get_full_name (user));
@@ -622,9 +627,6 @@ user_settings_dialog_get_data (OobsUser *user)
 	OobsGroup *group;
 	gchar *str;
 	gboolean password_changed;
-	
-	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_name");
-	oobs_user_set_login_name (user, gtk_entry_get_text (GTK_ENTRY (widget)));
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_real_name");
 	oobs_user_set_full_name (user, gtk_entry_get_text (GTK_ENTRY (widget)));
